@@ -25,13 +25,15 @@
 
 #include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
+#include <cstring>
 #include <stdarg.h>
 
+#if 0
+// Removed for VC 2008 compatibility. jhrg 4/23/08
 #ifdef WIN32
 #define vsnprintf _vsnprintf
 #endif
+#endif
 
 #include "AISDatabaseParser.h"
 #include "util.h"
@@ -39,6 +41,8 @@
 
 using namespace std;
 
+namespace libdap {
+
 static const not_used char *states[] =
     {
         "START",
@@ -426,3 +430,5 @@ AISDatabaseParser::intern(const string &database, AISResources *ais)
     ctxt->sax = NULL;
     xmlFreeParserCtxt(ctxt);
 }
+
+} // namespace libdap
