@@ -30,6 +30,9 @@
 #include "Error.h"
 #endif
 
+namespace libdap
+{
+
 /** Thrown when a client asks for the AIS resources for an unknown primary
     resource. */
 class NoSuchPrimaryResource : public Error
@@ -61,4 +64,6 @@ public:
     {}
 };
 
+} // namespace libdap
+
 #endif // ais_exceptions_h
