@@ -47,6 +47,8 @@
 
 using namespace std;
 
+namespace libdap {
+
 void
 Array::_duplicate(const Array &a)
 {
@@ -967,3 +969,5 @@ Array::dump(ostream &strm) const
     DapIndent::UnIndent() ;
 }
 
+} // namespace libdap
+
