@@ -29,12 +29,10 @@
 #include "config.h"
 
 static char id[] not_used =
-    { "$Id: ArrayGeoConstraint.cc 16612 2007-06-04 22:08:57Z jimg $"
+    { "$Id: ArrayGeoConstraint.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <math.h>
-#include <string.h>
-
+#include <cmath>
 #include <iostream>
 #include <sstream>
 
@@ -50,8 +48,8 @@ static char id[] not_used =
 #include "ce_functions.h"
 
 using namespace std;
-using namespace libdap;
 
+namespace libdap {
 
 /** Private initialization code. */
 void ArrayGeoConstraint::m_init()
@@ -206,3 +204,5 @@ void ArrayGeoConstraint::apply_constraint_to_data()
     }
 }
 
+} // namespace libdap
+
