@@ -33,9 +33,9 @@
 
 #include "config.h"
 
-static char rcsid[] not_used = "$Id: AttrTable.cc 17002 2007-08-27 19:16:51Z pwest $";
+static char rcsid[] not_used = "$Id: AttrTable.cc 18315 2008-03-03 20:14:44Z jimg $";
 
-#include <assert.h>
+#include <cassert>
 
 #include "AttrTable.h"
 
@@ -49,6 +49,8 @@ using std::string;
 using std::endl;
 using std::vector;
 
+namespace libdap {
+
 /** Convert an AttrType to it's string representation.
     @param at The Attribute Type.
     @return The type's string representation */
@@ -844,7 +846,7 @@ AttrTable::add_value_alias(AttrTable *das, const string &name,
 
     // If we've got a value to alias and it's being added at the top level of
     // the DAS, that's an error.
-    if (!at->is_container(iter) && this == das)
+    if (at && !at->is_container(iter) && this == das)
         throw Error(string("A value cannot be aliased to the top level of the DAS;\nOnly containers may be present at that level of the DAS."));
 
     if (simple_find(lname) != attr_end())
@@ -856,7 +858,7 @@ AttrTable::add_value_alias(AttrTable *das, const string &name,
     e->is_alias = true;
     e->aliased_to = lsource;
     e->type = get_attr_type(iter);
-    if (e->type == Attr_container)
+    if (at && e->type == Attr_container)
         e->attributes = at->get_attr_table(iter);
     else
         e->attr = (*iter)->attr;
@@ -1206,3 +1208,5 @@ AttrTable::dump(ostream &strm) const
     DapIndent::UnIndent() ;
 }
 
+} // namespace libdap
+
