@@ -39,14 +39,10 @@
 //#define DODS_DEBUG
 
 static char rcsid[] not_used =
-    { "$Id: Connect.cc 17002 2007-08-27 19:16:51Z pwest $"
+    { "$Id: Connect.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <stdio.h>
-#ifndef WIN32
-#include <unistd.h>
-#endif
-
+#include <cstring>
 #include <fstream>
 #include <algorithm>
 
@@ -64,7 +60,7 @@ using std::ifstream;
 using std::ofstream;
 using std::min;
 
-extern ObjectType get_type(const string &value);
+namespace libdap {
 
 /** This private method process data from both local and remote sources. It
     exists to eliminate duplication of code. */
@@ -127,24 +123,6 @@ Connect::process_data(DataDDS &data, Response *rs)
     }
 }
 
-// This function returns the ObjectType value that matches the given string.
-ObjectType
-get_type(const string &value)
-{
-    if (value == "dods_das")
-        return dods_das;
-    else if (value == "dods_dds")
-        return dods_dds;
-    else if (value == "dods_data")
-        return dods_data;
-    else if (value == "dods_error")
-        return dods_error;
-    else if (value == "web_error")
-        return web_error;
-    else
-        return unknown_type;
-}
-
 // Barely a parser... This is used when reading from local sources of DODS
 // Data objects. It simulates the important actions of the libwww MIME header
 // parser. Those actions fill in certain fields in the Connect object. jhrg
@@ -993,3 +971,5 @@ Connect::is_cache_enabled()
     DBGN(cerr << "exiting" << endl);
     return status;
 }
+
+} // namespace libdap
