@@ -25,7 +25,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: ConstraintEvaluator.cc 16936 2007-08-13 20:01:09Z jimg $"
+    {"$Id: ConstraintEvaluator.cc 17856 2008-02-02 21:25:59Z pwest $"
     };
 
 #include "ConstraintEvaluator.h"
@@ -35,8 +35,6 @@ static char rcsid[] not_used =
 #include "ce_parser.h"
 #include "debug.h"
 
-using namespace libdap;
-
 struct yy_buffer_state;
 yy_buffer_state *ce_expr_scan_string(const char *str);
 int ce_exprparse(void *arg);
@@ -46,6 +44,8 @@ void ce_expr_switch_to_buffer(void *new_buffer);
 void ce_expr_delete_buffer(void * buffer);
 void *ce_expr_string(const char *yy_str);
 
+namespace libdap {
+
 ConstraintEvaluator::ConstraintEvaluator()
 {
     register_functions(*this);
@@ -369,3 +369,5 @@ ConstraintEvaluator::parse_constraint(const string &constraint, DDS &dds)
 
     ce_expr_delete_buffer(buffer);
 }
+
+} // namespace libdap
