@@ -37,15 +37,18 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: DAS.cc 17002 2007-08-27 19:16:51Z pwest $"
+    {"$Id: DAS.cc 18319 2008-03-03 21:42:36Z jimg $"
     };
 
 
-#include <stdio.h>
+#include <cstdio>
+
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #ifdef WIN32
 #include <io.h>
-#else
-#include <unistd.h>
 #endif
 
 #include <iostream>
@@ -69,6 +72,8 @@ extern void *das_buffer(FILE *fp);
 extern void dasrestart(FILE *yyin);
 extern int dasparse(void *arg); // defined in das.tab.c
 
+namespace libdap {
+
 AttrTable *
 DAS::das_find(string name)
 {
@@ -319,3 +324,5 @@ DAS::dump(ostream &strm) const
     DapIndent::UnIndent() ;
 }
 
+} // namespace libdap
+
