@@ -38,8 +38,7 @@
 #define _das_h 1
 
 
-#include <stdio.h>
-
+#include <cstdio>
 #include <string>
 #include <iostream>
 
@@ -51,6 +50,9 @@
 
 using std::cout;
 
+namespace libdap
+{
+
 /** @brief Hold attribute data for a DAP2 dataset.
 
     The Data Attribute Structure is a set of name-value pairs used to
@@ -155,4 +157,6 @@ public:
     virtual void dump(ostream &strm) const ;
 };
 
+} // namespace libdap
+
 #endif // _das_h
