@@ -25,9 +25,7 @@
 
 #include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdarg.h>
+#include <cstring>
 
 #include "BaseType.h"
 #include "Constructor.h"
@@ -36,6 +34,8 @@
 #include "util.h"
 #include "debug.h"
 
+namespace libdap {
+
 static const not_used char *states[] =
     {
         "start",
@@ -328,7 +328,9 @@ void DDXParser::process_dimension(const char **attrs)
     if (check_required_attribute(string("size"))) {
         set_state(inside_dimension);
         Array *ap = dynamic_cast < Array * >(bt_stack.top());
-
+		if (!ap)
+			ddx_fatal_error(this, "Parse error: Expected an array variable.");
+			
         ap->append_dim(atoi(attributes["size"].c_str()),
                        attributes["name"]);
     }
@@ -497,6 +499,9 @@ void DDXParser::ddx_end_document(DDXParser * parser)
     // to the DDS.
     Constructor *cp =
         dynamic_cast < Constructor * >(parser->bt_stack.top());
+    if (!cp)
+    	ddx_fatal_error(parser, "Parse error: Expected a Structure, Sequence or Grid variable.");
+    	
     for (Constructor::Vars_iter i = cp->var_begin(); i != cp->var_end();
          ++i)
         parser->dds->add_var(*i);
@@ -1021,3 +1026,5 @@ void DDXParser::intern(const string & document, DDS * dest_dds,
 
     cleanup_parse(context);
 }
+
+} // namespace libdap
