@@ -26,13 +26,14 @@
 #ifndef event_handler_h
 #define event_handler_h
 
-#include <stdio.h>
-
 #include <iostream>
 
 //#include "Error.h"
 //#include "cgi_util.h"
 
+namespace libdap
+{
+
 /** An abstract class which provides a hook method used by SignalHandler.
 
     Based on "Applying Design Patterns to Simplify Signal Handling", Douglas
@@ -71,4 +72,6 @@ public:
     }
 };
 
+} // namespace libdap
+
 #endif // event_handler_h
