@@ -39,11 +39,9 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: Float32.cc 17002 2007-08-27 19:16:51Z pwest $"
+    {"$Id: Float32.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <stdlib.h>
-
 #include "Float32.h"
 #include "DDS.h"
 #include "util.h"
@@ -56,6 +54,8 @@ static char rcsid[] not_used =
 using std::cerr;
 using std::endl;
 
+namespace libdap {
+
 /** The Float32 constructor accepts only the name of the variable. The
     name may be omitted, which will create a nameless variable. This
     may be adequate for some applications.
@@ -270,3 +270,5 @@ Float32::dump(ostream &strm) const
     DapIndent::UnIndent() ;
 }
 
+} // namespace libdap
+
