@@ -38,18 +38,15 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: Float64.cc 17002 2007-08-27 19:16:51Z pwest $"
+    {"$Id: Float64.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <stdlib.h>
-
 #include <iomanip>
 
 #include "Float64.h"
 #include "DDS.h"
 #include "util.h"
 #include "parser.h"
-//#include "ce_expr.tab.h"
 #include "Operators.h"
 #include "dods-limits.h"
 #include "InternalErr.h"
@@ -58,6 +55,8 @@ static char rcsid[] not_used =
 using std::cerr;
 using std::endl;
 
+namespace libdap {
+
 /** The Float64 constructor requires only the name of the variable
     to be created.  The name may be omitted, which will create a
     nameless variable.  This may be adequate for some applications.
@@ -278,3 +277,5 @@ Float64::dump(ostream &strm) const
     DapIndent::UnIndent() ;
 }
 
+} // namespace libdap
+
