@@ -29,17 +29,14 @@
 #include "config.h"
 
 static char id[] not_used =
-    { "$Id: GeoConstraint.cc 16967 2007-08-20 23:39:01Z jimg $"
+    { "$Id: GeoConstraint.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <math.h>
-#include <string.h>
-
+#include <cstring>
+#include <cmath>
 #include <iostream>
 #include <sstream>
-#ifdef WIN32
 #include <algorithm>  //  for find_if
-#endif
 
 //#define DODS_DEBUG2
 
@@ -54,7 +51,8 @@ static char id[] not_used =
 #include "util.h"
 
 using namespace std;
-using namespace libdap;
+
+namespace libdap {
 
 /** If an attribute value is quoted, remove the quotes.
 
@@ -62,6 +60,7 @@ using namespace libdap;
     present.
 
     @param value A value-result parameter. */
+/* FIXME: There is one defined in ce_functions
 void remove_quotes(string & value)
 {
     if (!value.empty() && value[0] == '"'
@@ -72,6 +71,7 @@ void remove_quotes(string & value)
 
     return;
 }
+*/
 
 /** This is used with find_if(). The GeoConstraint class holds a set of strings
     which are prefixes for variable names. Using the regular find() locates
@@ -625,3 +625,5 @@ void GeoConstraint::set_bounding_box(double left, double top,
 
     d_bounding_box_set = true;
 }
+
+} // namespace libdap
