@@ -49,6 +49,8 @@
 
 using namespace std;
 
+namespace libdap {
+
 void
 Grid::_duplicate(const Grid &s)
 {
@@ -929,3 +931,5 @@ Grid::dump(ostream &strm) const
     DapIndent::UnIndent() ;
 }
 
+} // namespace libdap
+
