@@ -27,7 +27,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    { "$Id: HTTPConnect.cc 18650 2008-04-25 20:47:50Z jimg $"
+    { "$Id: HTTPConnect.cc 18763 2008-05-20 19:22:36Z jimg $"
     };
 
 #ifdef HAVE_UNISTD_H
@@ -509,8 +509,7 @@ HTTPConnect::url_uses_no_proxy_for(const string &url) throw()
     @param rcr A pointer to the RCReader object which holds configuration
     file information to be used by this virtual connection. */
 
-HTTPConnect::HTTPConnect(RCReader *rcr) throw(Error, InternalErr)
-        : d_username(""), d_password("")
+HTTPConnect::HTTPConnect(RCReader *rcr) : d_username(""), d_password("")
 {
     d_accept_deflate = rcr->get_deflate();
     d_rcr = rcr;
@@ -529,7 +528,7 @@ HTTPConnect::HTTPConnect(RCReader *rcr) throw(Error, InternalErr)
     // HTTPCache::instance returns a valid ptr or 0.
     if (d_rcr->get_use_cache())
         d_http_cache = HTTPCache::instance(d_rcr->get_dods_cache_root(),
-                                           false);
+                                           true);
     else
         d_http_cache = 0;
 
@@ -751,100 +750,186 @@ close_temp(FILE *s, const string &name)
     @exception InternalErr Thrown if a temporary file to hold the response
     could not be opened. */
 
-HTTPResponse *
-HTTPConnect::caching_fetch_url(const string &url)
-{
-    DBG(cerr << "Is this URL (" << url << ") in the cache?... ");
+HTTPResponse * HTTPConnect::caching_fetch_url(const string &url) {
+	DBG(cerr << "Is this URL (" << url << ") in the cache?... ");
 
-    if (d_http_cache->is_url_in_cache(url)) { // url in cache
-        DBGN(cerr << "yes... ");
+	vector<string> *headers = new vector<string>;
+	FILE *s = d_http_cache->get_cached_response(url, *headers);
+	if (!s) {
+		// url not in cache; get it and cache it
+		DBGN(cerr << "no; getting response and caching." << endl);
+		time_t now = time(0);
+		HTTPResponse *rs = plain_fetch_url(url);
+		d_http_cache->cache_response(url, now, *(rs->get_headers()),
+				rs->get_stream());
 
-        if (d_http_cache->is_url_valid(url)) { // url in cache and valid
-            DBGN(cerr << "and it's valid; using cached response." << endl);
+		return rs;
+	}
+	else { // url in cache
+		DBGN(cerr << "yes... ");
 
-            vector<string> *headers = new vector<string>;;
-            FILE *s = d_http_cache->get_cached_response(url, *headers);
-            HTTPCacheResponse *crs = new HTTPCacheResponse(s, 200, headers, d_http_cache);
+		if (d_http_cache->is_url_valid(url)) { // url in cache and valid
+			DBGN(cerr << "and it's valid; using cached response." << endl);
+			HTTPCacheResponse *crs = new HTTPCacheResponse(s, 200, headers, d_http_cache);
+			return crs;
+		} 
+		else { // url in cache but not valid; validate
+			DBGN(cerr << "but it's not valid; validating... ");
 
-            return crs;
-        }
-        else {   // url in cache but not valid; validate
-            DBGN(cerr << "but it's not valid; validating... ");
+			d_http_cache->release_cached_response(s);
 
-            // *** auto_ptr??? resp_hdrs not deleted! 10/10/03 jhrg
-            vector<string> *resp_hdrs = new vector<string>;
-            vector<string> cond_hdrs
-		= d_http_cache->get_conditional_request_headers(url);
-            FILE *body = 0;
-            string dods_temp = get_temp_file(body);
-            time_t now = time(0); // When was the request made (now).
-            long http_status;
+			vector<string> *resp_hdrs = new vector<string>;
+			vector<string> cond_hdrs =
+					d_http_cache->get_conditional_request_headers(url);
+			FILE *body = 0;
+			string dods_temp = get_temp_file(body);
+			time_t now = time(0); // When was the request made (now).
+			long http_status;
 
-            try {
-                http_status = read_url(url, body, resp_hdrs, &cond_hdrs);
-                rewind(body);
-            }
-            catch (Error &e) {
-                close_temp(body, dods_temp);
-                throw;
-            }
+			try {
+				http_status = read_url(url, body, resp_hdrs, &cond_hdrs);
+				rewind(body);
+			}
+			catch (Error &e) {
+				close_temp(body, dods_temp);
+				throw;
+			}
 
-            switch (http_status) {
-            case 200: {  // New headers and new body
-                    DBGN(cerr << "read a new response; caching." << endl);
+			switch (http_status) {
+			case 200: { // New headers and new body
+				DBGN(cerr << "read a new response; caching." << endl);
 
-                    d_http_cache->cache_response(url, now, *resp_hdrs, body);
-                    HTTPResponse *rs = new HTTPResponse(body, http_status, resp_hdrs,
-                                                        dods_temp);
+				d_http_cache->cache_response(url, now, *resp_hdrs, body);
+				HTTPResponse *rs = new HTTPResponse(body, http_status, resp_hdrs,
+						dods_temp);
 
-                    return rs;
-                }
-                break;
+				return rs;
+			}
 
-            case 304: {  // Just new headers, use cached body
-                    DBGN(cerr << "cached response valid; updating." << endl);
+			case 304: { // Just new headers, use cached body
+				DBGN(cerr << "cached response valid; updating." << endl);
 
-                    close_temp(body, dods_temp);
-                    d_http_cache->update_response(url, now, *resp_hdrs);
+				close_temp(body, dods_temp);
+				d_http_cache->update_response(url, now, *resp_hdrs);
 
-                    vector<string> *headers = new vector<string>;;
-                    FILE *s = d_http_cache->get_cached_response(url, *headers);
-                    HTTPCacheResponse *crs
-                    = new HTTPCacheResponse(s, 304, headers, d_http_cache);
-                    return crs;
-                }
-                break;
+				vector<string> *headers = new vector<string>;
+				FILE *hs = d_http_cache->get_cached_response(url, *headers);
+				HTTPCacheResponse *crs = new HTTPCacheResponse(hs, 304, headers, d_http_cache);
+				return crs;
+			}
 
-            default: {  // Oops.
-                    close_temp(body, dods_temp);
-                    if (http_status >= 400) {
-                        string msg = "Error while reading the URL: ";
-                        msg += url;
-                        msg += ".\nThe OPeNDAP server returned the following message:\n";
-                        msg += http_status_to_string(http_status);
-                        throw Error(msg);
-                    }
-                    else
-                        throw InternalErr(__FILE__, __LINE__,
-                                          "Bad response from the HTTP server: " + long_to_string(http_status));
-                }
-                break;
-            }
-        }
-    }
-    else {   // url not in cache; get it and cache it
-        DBGN(cerr << "no; getting response and caching." << endl);
-        time_t now = time(0);
-        HTTPResponse *rs = plain_fetch_url(url);
-        d_http_cache->cache_response(url, now, *(rs->get_headers()),
-                                     rs->get_stream());
+			default: { // Oops.
+				close_temp(body, dods_temp);
+				if (http_status >= 400) {
+					string msg = "Error while reading the URL: ";
+					msg += url;
+					msg
+							+= ".\nThe OPeNDAP server returned the following message:\n";
+					msg += http_status_to_string(http_status);
+					throw Error(msg);
+				} else {
+					throw InternalErr(__FILE__, __LINE__,
+							"Bad response from the HTTP server: " + long_to_string(http_status));
+				}
+			}
 
-        return rs;
-    }
-
-    throw InternalErr(__FILE__, __LINE__, "Unexpected cache response.");
+			}
+		}
+	}
+	
+	throw InternalErr(__FILE__, __LINE__, "Should never get here");
 }
 
+#if 0
+HTTPResponse * HTTPConnect::caching_fetch_url(const string &url) {
+	DBG(cerr << "Is this URL (" << url << ") in the cache?... ");
+
+	if (d_http_cache->is_url_in_cache(url)) { // url in cache
+		DBGN(cerr << "yes... ");
+
+		if (d_http_cache->is_url_valid(url)) { // url in cache and valid
+			DBGN(cerr << "and it's valid; using cached response." << endl);
+
+			vector<string> *headers = new vector<string>;
+			FILE *s = d_http_cache->get_cached_response(url, *headers);
+			HTTPCacheResponse *crs = new HTTPCacheResponse(s, 200, headers, d_http_cache);
+
+			return crs;
+		} else { // url in cache but not valid; validate
+			DBGN(cerr << "but it's not valid; validating... ");
+
+			// *** auto_ptr??? resp_hdrs not deleted! 10/10/03 jhrg
+			vector<string> *resp_hdrs = new vector<string>;
+			vector<string> cond_hdrs =
+					d_http_cache->get_conditional_request_headers(url);
+			FILE *body = 0;
+			string dods_temp = get_temp_file(body);
+			time_t now = time(0); // When was the request made (now).
+			long http_status;
+
+			try {
+				http_status = read_url(url, body, resp_hdrs, &cond_hdrs);
+				rewind(body);
+			}
+			catch (Error &e) {
+				close_temp(body, dods_temp);
+				throw;
+			}
+
+			switch (http_status) {
+			case 200: { // New headers and new body
+				DBGN(cerr << "read a new response; caching." << endl);
+
+				d_http_cache->cache_response(url, now, *resp_hdrs, body);
+				HTTPResponse *rs = new HTTPResponse(body, http_status, resp_hdrs,
+						dods_temp);
+
+				return rs;
+			}
+				break;
+
+			case 304: { // Just new headers, use cached body
+				DBGN(cerr << "cached response valid; updating." << endl);
+
+				close_temp(body, dods_temp);
+				d_http_cache->update_response(url, now, *resp_hdrs);
+
+				vector<string> *headers = new vector<string>;
+				FILE *s = d_http_cache->get_cached_response(url, *headers);
+				HTTPCacheResponse *crs = new HTTPCacheResponse(s, 304, headers, d_http_cache);
+				return crs;
+			}
+				break;
+
+			default: { // Oops.
+				close_temp(body, dods_temp);
+				if (http_status >= 400) {
+					string msg = "Error while reading the URL: ";
+					msg += url;
+					msg += ".\nThe OPeNDAP server returned the following message:\n";
+					msg += http_status_to_string(http_status);
+					throw Error(msg);
+				} else {
+					throw InternalErr(__FILE__, __LINE__,
+							"Bad response from the HTTP server: " + long_to_string(http_status));
+				}
+			}
+				break;
+			}
+		}
+	} else { // url not in cache; get it and cache it
+		DBGN(cerr << "no; getting response and caching." << endl);
+		time_t now = time(0);
+		HTTPResponse *rs = plain_fetch_url(url);
+		d_http_cache->cache_response(url, now, *(rs->get_headers()),
+				rs->get_stream());
+
+		return rs;
+	}
+
+	throw InternalErr(__FILE__, __LINE__, "Unexpected cache response.");
+}
+#endif
 
 /** Dereference a URL and load its body into a temporary file. This
     method ignores the HTTP cache.
