@@ -37,16 +37,13 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: Int32.cc 17002 2007-08-27 19:16:51Z pwest $"
+    {"$Id: Int32.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <stdlib.h>
-
 #include "Int32.h"
 #include "DDS.h"
 #include "util.h"
 #include "parser.h"
-//#include "ce_expr.tab.h"
 #include "Operators.h"
 #include "dods-limits.h"
 #include "debug.h"
@@ -56,6 +53,8 @@ static char rcsid[] not_used =
 using std::cerr;
 using std::endl;
 
+namespace libdap {
+
 /** The Int32 constructor requires only the name of the variable
     to be created.  The name may be omitted, which will create a
     nameless variable.  This may be adequate for some applications.
@@ -270,3 +269,5 @@ Int32::dump(ostream &strm) const
     DapIndent::UnIndent() ;
 }
 
+} // namespace libdap
+
