@@ -34,14 +34,14 @@
 
     @author: jose */
 
+// #define DODS_DEBUG
 #include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
+#include <cstring>
 
+#include <unistd.h>  // for stat
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
 
 #ifdef WIN32
 #define FALSE 0
@@ -65,6 +65,8 @@
 
 using namespace std;
 
+namespace libdap {
+
 RCReader* RCReader::_instance = 0;
 
 // This variable (instance_control) is used to ensure that in a MT
@@ -88,7 +90,7 @@ RCReader::write_rc_file(const string &pathname)
     if (fpo) {
         // This means we just created the file.  We will now save
         // the defaults in it for future use.
-        fpo << "# OPeNDAP client configuation file. See the OPeNDAP" << endl;
+        fpo << "# OPeNDAP client configuration file. See the OPeNDAP" << endl;
         fpo << "# users guide for information." << endl;
         fpo << "USE_CACHE=" << _dods_use_cache << endl;
         fpo << "# Cache and object size are given in megabytes (20 ==> 20Mb)."
@@ -107,11 +109,15 @@ RCReader::write_rc_file(const string &pathname)
         fpo << "# will only work with signed certificates." << endl;
         fpo << "VALIDATE_SSL=" << d_validate_ssl << endl;
 
-        fpo << "# Proxy configuration:" << endl;
-        fpo << "# PROXY_SERVER=<protocol>,<[username:password@]host[:port]>"
+        fpo << "# Proxy configuration (optional parts in []s)." << endl;
+	fpo << "# You may also use the 'http_proxy' environment variable" 
+	    << endl;
+	fpo << "# but a value in this file will override that env variable."
+	    << endl;
+        fpo << "# PROXY_SERVER=[http://][username:password@]host[:port]"
         << endl;
         if (!d_dods_proxy_server_host.empty()) {
-            fpo << "PROXY_SERVER=" <<  d_dods_proxy_server_protocol << ","
+            fpo << "PROXY_SERVER=" <<  d_dods_proxy_server_protocol << "://"
             << (d_dods_proxy_server_userpw.empty()
                 ? ""
                 : d_dods_proxy_server_userpw + "@")
@@ -119,10 +125,9 @@ RCReader::write_rc_file(const string &pathname)
             + ":" + long_to_string(d_dods_proxy_server_port) << endl;
         }
 
-        fpo << "# NO_PROXY_FOR=<protocol>,<host|domain>" << endl;
+        fpo << "# NO_PROXY_FOR=<host|domain>" << endl;
         if (!d_dods_no_proxy_for_host.empty()) {
-            fpo << "NO_PROXY_FOR=" << d_dods_no_proxy_for_protocol << ","
-            << d_dods_no_proxy_for_host << endl;
+            fpo << "NO_PROXY_FOR=" << d_dods_no_proxy_for_host << endl;
         }
 
         fpo << "# AIS_DATABASE=<file or url>" << endl;
@@ -204,15 +209,32 @@ RCReader::read_rc_file(const string &pathname)
             else if ((strncmp(tempstr, "PROXY_SERVER", 12) == 0)
                      && tokenlength == 12) {
                 // Setup a proxy server for all requests.
+		// The original syntax was <protocol>,<machine> where the
+		// machine could also contain the user/pass and port info.
+		// Support that but also support machine prefixed by
+		// 'http://' with and without the '<protocol>,' prefix. jhrg
+		// 4/21/08 (see bug 1095).
                 string proxy = value;
                 string::size_type comma = proxy.find(',');
 
-                // Since the protocol is required, the comma *must* be
-                // present. We could throw an Error on the malformed line...
-                if (comma == string::npos)
-                    continue;
-                d_dods_proxy_server_protocol = proxy.substr(0, comma);
-                proxy = proxy.substr(comma + 1);
+                // Since the <protocol> is now optional, the comma might be
+                // here. If it is, check that the protocol given is http.
+                if (comma != string::npos) {
+		    d_dods_proxy_server_protocol = proxy.substr(0, comma);
+		    downcase(d_dods_proxy_server_protocol);
+		    if (d_dods_proxy_server_protocol != "http")
+			throw Error("The only supported protocol for a proxy server is \"HTTP\". Correct your \".dodsrc\" file.");
+		    proxy = proxy.substr(comma + 1);
+		}
+		else {
+		    d_dods_proxy_server_protocol = "http";
+		}
+
+		// Look for a 'protocol://' prefix; skip if found
+		string::size_type protocol = proxy.find("://");
+		if (protocol != string::npos) {
+		    proxy = proxy.substr(protocol + 3);
+		}
 
                 // Break apart into userpw, host and port.
                 string::size_type at_sign = proxy.find('@');
@@ -228,20 +250,11 @@ RCReader::read_rc_file(const string &pathname)
                 if (colon != string::npos) {
                     d_dods_proxy_server_host = proxy.substr(0, colon);
                     d_dods_proxy_server_port
-                    = strtol(proxy.substr(colon + 1).c_str(), 0, 0);
+			= strtol(proxy.substr(colon + 1).c_str(), 0, 0);
                 }
                 else {
                     d_dods_proxy_server_host = proxy;
-                    // No port given, look at protocol or throw
-                    if (d_dods_proxy_server_protocol == "http")
-                        d_dods_proxy_server_port = 80;
-                    else if (d_dods_proxy_server_protocol == "https")
-                        d_dods_proxy_server_port = 443;
-                    else if (d_dods_proxy_server_protocol == "ftp")
-                        d_dods_proxy_server_port = 21;
-                    else throw Error("Could not determine the port to use for proxy '"
-                                         + d_dods_proxy_server_host
-                                         + ".' Please check your .dodsrc file.");
+		    d_dods_proxy_server_port = 80;
                 }
             }
             else if ((strncmp(tempstr, "NO_PROXY_FOR", 12) == 0)
@@ -252,11 +265,16 @@ RCReader::read_rc_file(const string &pathname)
 
                 // Since the protocol is required, the comma *must* be
                 // present. We could throw an Error on the malformed line...
-                if (comma == string::npos)
-                    continue;
-                d_dods_no_proxy_for_protocol = no_proxy.substr(0, comma);
-                d_dods_no_proxy_for_host = no_proxy.substr(comma + 1);
-                d_dods_no_proxy_for = true;
+                if (comma == string::npos) {
+		    d_dods_no_proxy_for_protocol = "http";
+		    d_dods_no_proxy_for_host = no_proxy;
+		    d_dods_no_proxy_for = true;
+		}
+		else {
+		    d_dods_no_proxy_for_protocol = no_proxy.substr(0, comma);
+		    d_dods_no_proxy_for_host = no_proxy.substr(comma + 1);
+		    d_dods_no_proxy_for = true;
+		}
             }
         }
 
@@ -276,17 +294,23 @@ RCReader::read_rc_file(const string &pathname)
 string
 RCReader::check_string(string env_var)
 {
+	DBG(cerr << "Entering check_string... (" << env_var << ")" << endl);
     struct stat stat_info;
 
-    if (stat(env_var.c_str(), &stat_info) != 0)
+	if (stat(env_var.c_str(), &stat_info) != 0) {
+		DBG(cerr << "stat returned non-zero" << endl);
         return "";  // ENV VAR not a file or dir, bail
+	}
 
-    if (S_ISREG(stat_info.st_mode))
+	if (S_ISREG(stat_info.st_mode)) {
+		DBG(cerr << "S_ISREG: " << S_ISREG(stat_info.st_mode) << endl);
         return env_var;  // ENV VAR is a file, use it
+	}
 
     // ENV VAR is a directory, does it contain .dodsrc? Can we create
     // .dodsrc if it's not there?
     if (S_ISDIR(stat_info.st_mode)) {
+		DBG(cerr << "S_ISDIR: " << S_ISDIR(stat_info.st_mode) << endl);
         if (*env_var.rbegin() != DIR_SEP_CHAR) // Add trailing / if missing
             env_var += DIR_SEP_STRING;
         // Trick: set d_cache_root here in case we're going to create the
@@ -296,21 +320,26 @@ RCReader::check_string(string env_var)
         d_cache_root = env_var + string(".dods_cache") + DIR_SEP_STRING;
         env_var += ".dodsrc";
         if (stat(env_var.c_str(), &stat_info) == 0 &&
-            S_ISREG(stat_info.st_mode))
+			S_ISREG(stat_info.st_mode)) {
+			DBG(cerr << "Found .dodsrc in \"" << env_var << "\"" << endl);
             return env_var; // Found .dodsrc in ENV VAR
+		}
 
         // Didn't find .dodsrc in ENV VAR and ENV VAR is a directory; try to
         // create it. Note write_rc_file uses d_cache_root (set above) when
         // it creates the RC file's contents.
-        if (write_rc_file(env_var))
+		if (write_rc_file(env_var)) {
+			DBG(cerr << "Wrote .dodsrc in \"" << env_var << "\"" << endl);
             return env_var;
+		}
     }
 
-    // If we're here, then we've not found or created the RC file.
+    // If we're here, then we've neither found nor created the RC file.
+	DBG(cerr << "could neither find nor create a .dodsrc file" << endl);
     return "";
 }
 
-/** Examine an environment variable. If the env variable is set, then If
+/** Examine an environment variable. If the env variable is set, then if
     this is the name of a file, use that as the name of the RC file. If this
     is the name of a directory, look in that directory for a file called
     .dodsrc. If there's no such file, create it using default values for its
@@ -347,6 +376,7 @@ RCReader::RCReader() throw(Error)
     d_validate_ssl = 1;
 
     //flags for PROXY_SERVER=<protocol>,<host url>
+    // New syntax PROXY_SERVER=[http://][user:pw@]host[:port]
     d_dods_proxy_server_protocol = "";
     d_dods_proxy_server_host = "";
     d_dods_proxy_server_port = 0;
@@ -354,6 +384,7 @@ RCReader::RCReader() throw(Error)
 
     _dods_proxy_server_host_url = ""; // deprecated
 
+    // PROXY_FOR is deprecated.
     // flags for PROXY_FOR=<regex>,<proxy host url>,<flags>
     _dods_proxy_for = false; // true if proxy_for is used.
     _dods_proxy_for_regexp = "";
@@ -361,13 +392,14 @@ RCReader::RCReader() throw(Error)
     _dods_proxy_for_regexp_flags = 0;
 
     //flags for NO_PROXY_FOR=<protocol>,<host>,<port>
+    // New syntax NO_PROXY_FOR=<host|domain>
     d_dods_no_proxy_for = false;
-    d_dods_no_proxy_for_protocol = "";
+    d_dods_no_proxy_for_protocol = ""; // deprecated
     d_dods_no_proxy_for_host = "";
     // default to port 0 if not specified. This means all ports. Using 80
     // will fail when the URL does not contain the port number. That's
     // probably a bug in libwww. 10/23/2000 jhrg
-    _dods_no_proxy_for_port = 0;
+    _dods_no_proxy_for_port = 0; // deprecated
 
 #ifdef WIN32
     string homedir = string("C:") + string(DIR_SEP_STRING) + string("Dods");
@@ -384,6 +416,7 @@ RCReader::RCReader() throw(Error)
     if (d_rc_file_path.empty())
         d_rc_file_path = check_env_var("HOME");
 #endif
+	DBG(cerr << "Looking for .dodsrc in: " << d_rc_file_path << endl);
 
     if (!d_rc_file_path.empty())
         read_rc_file(d_rc_file_path);
@@ -406,20 +439,24 @@ RCReader::delete_instance()
 void
 RCReader::initialize_instance()
 {
-    DBG(cerr << "RCReader::initialize_instance() ... ");
+    DBGN(cerr << "RCReader::initialize_instance() ... ");
 
     RCReader::_instance = new RCReader;
     atexit(RCReader::delete_instance);
 
-    DBGN(cerr << "exiting." << endl);
+    DBG(cerr << "exiting." << endl);
 }
 
 RCReader*
 RCReader::instance()
 {
+	DBG(cerr << "Entring RCReader::instance" << endl);
     // The instance_control variable is defined at the top of this file.
     // 08/07/02 jhrg
     pthread_once(&instance_control, initialize_instance);
-
+	
+	DBG(cerr << "Instance value: " << hex << _instance << dec << endl);
     return _instance;
 }
+
+} // namespace libdap
