@@ -27,6 +27,7 @@
 #define response_h
 
 #include <cstdio>
+#include <string>
 
 #ifndef _debug_h
 #include "debug.h"
@@ -34,6 +35,9 @@
 
 using namespace std;
 
+#include "ObjectType.h"
+#include "InternalErr.h"
+
 namespace libdap
 {
 
