@@ -54,6 +54,8 @@
 
 using namespace std;
 
+namespace libdap {
+
 static const unsigned char end_of_sequence = 0xA5; // binary pattern 1010 0101
 static const unsigned char start_of_instance = 0x5A; // binary pattern 0101 1010
 
@@ -1527,3 +1529,5 @@ Sequence::dump(ostream &strm) const
     DapIndent::UnIndent() ;
 }
 
+} // namespace libdap
+
