@@ -60,6 +60,9 @@
 // FIXME
 #include "XDRUtils.h"
 
+namespace libdap
+{
+
 /** The type BaseTypeRow is used to store single rows of values in an
     instance of Sequence. Values are stored in instances of BaseType. */
 typedef vector<BaseType *> BaseTypeRow;
@@ -343,4 +346,6 @@ public:
     virtual void dump(ostream &strm) const ;
 };
 
+} // namespace libdap
+
 #endif //_sequence_h
