@@ -37,16 +37,13 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: UInt16.cc 17002 2007-08-27 19:16:51Z pwest $"
+    {"$Id: UInt16.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <stdlib.h>
-
 #include "UInt16.h"
 #include "DDS.h"
 #include "util.h"
 #include "parser.h"
-//#include "ce_expr.tab.h"
 #include "Operators.h"
 #include "dods-limits.h"
 #include "debug.h"
@@ -55,6 +52,8 @@ static char rcsid[] not_used =
 using std::cerr;
 using std::endl;
 
+namespace libdap {
+
 UInt16::UInt16(const string &n)
         : BaseType(n, dods_uint16_c)
 {}
@@ -256,3 +255,5 @@ UInt16::dump(ostream &strm) const
     DapIndent::UnIndent() ;
 }
 
+} // namespace libdap
+
