@@ -37,25 +37,23 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: UInt32.cc 17002 2007-08-27 19:16:51Z pwest $"
+    {"$Id: UInt32.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <stdlib.h>
-
 #include "UInt32.h"
 #include "DDS.h"
 #include "util.h"
 #include "parser.h"
-//#include "ce_expr.tab.h"
 #include "Operators.h"
 #include "dods-limits.h"
 #include "debug.h"
 #include "InternalErr.h"
 
-
 using std::cerr;
 using std::endl;
 
+namespace libdap {
+
 UInt32::UInt32(const string &n)
         : BaseType(n, dods_uint32_c)
 {}
@@ -258,3 +256,5 @@ UInt32::dump(ostream &strm) const
     DapIndent::UnIndent() ;
 }
 
+} // namespace libdap
+
