@@ -49,6 +49,9 @@
 #include "ConstraintEvaluator.h"
 #endif
 
+namespace libdap
+{
+
 /** @brief Holds a 32-bit unsigned integer.
 
     @see BaseType */
@@ -103,5 +106,7 @@ public:
     virtual void dump(ostream &strm) const ;
 };
 
+} // namespace libdap
+
 #endif // _uint32_h
 
