@@ -36,8 +36,10 @@
 
 #include "config.h"
 
+#include <cstring>
+
 static char rcsid[] not_used =
-    { "$Id: Vector.cc 17489 2007-11-26 23:18:58Z pwest $"
+    { "$Id: Vector.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
 //#define DODS_DEBUG
@@ -50,10 +52,11 @@ static char rcsid[] not_used =
 #include "debug.h"
 #include "InternalErr.h"
 
-
 using std::cerr;
 using std::endl;
 
+namespace libdap {
+
 void Vector::_duplicate(const Vector & v)
 {
     _length = v._length;
@@ -771,7 +774,8 @@ unsigned int Vector::buf2val(void **val)
     if (!val)
         throw InternalErr(__FILE__, __LINE__, "NULL pointer.");
 
-    int wid = width();          // This is the width computed using length(). The
+    unsigned int wid = static_cast<unsigned int>(width());
+    // This is the width computed using length(). The
     // length() property is changed when a projection
     // constraint is applied. Thus this is the number of
     // bytes in the buffer given the current constraint.
@@ -1298,7 +1302,30 @@ Vector::dump(ostream &strm) const
         strm << DapIndent::LMarg << d_str[i] << endl ;
     }
     DapIndent::UnIndent() ;
-    strm << DapIndent::LMarg << "_buf: " << (void *)_buf << endl ;
+    if( _buf )
+    {
+	switch( _var->type() )
+	{
+	    case dods_byte_c:
+	    {
+		strm << DapIndent::LMarg << "_buf: " ;
+		strm.write( _buf, _length ) ;
+		strm << endl ;
+	    }
+	    break ;
+	    default:
+	    {
+		strm << DapIndent::LMarg << "_buf: " << (void *)_buf << endl ;
+	    }
+	    break ;
+	}
+    }
+    else
+    {
+	strm << DapIndent::LMarg << "_buf: EMPTY" << endl ;
+    }
     DapIndent::UnIndent() ;
 }
 
+} // namespace libdap
+
