@@ -70,6 +70,8 @@
 
 using namespace std;
 
+namespace libdap {
+
 // The next four functions were originally defined static, but I removed that
 // to make testing them (see generalUtilTest.cc) easier to write. 5/7/2001
 // jhrg
@@ -355,7 +357,6 @@ unescattr(string s)
 
     DBG(cerr << "0XX" << s << "XXX" << endl);
     // unescape any escaped backslashes
-    index = 0;
     index = esc_esc.search(s.c_str(), s.length(), matchlen, 0);
     while (index < s.length()) {
         DBG(cerr << "1aXX" << s << "XXX index: " << index << endl);
@@ -402,3 +403,5 @@ munge_error_message(string msg)
     return msg;
 }
 
+} // namespace libdap
+
