@@ -36,16 +36,16 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    { "$Id: getdap.cc 17299 2007-10-24 19:39:50Z jimg $"
+    { "$Id: getdap.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <stdio.h>
 #ifdef WIN32
 #include <io.h>
 #include <fcntl.h>
 #endif
 
 #include <GetOpt.h>
+#include <cstring>
 #include <string>
 
 #include "AISConnect.h"
@@ -55,9 +55,11 @@ static char rcsid[] not_used =
 using std::cerr;
 using std::endl;
 
+using namespace libdap ;
+
 const char *version = CVER " (" DVR " DAP/" DAP_PROTOCOL_VERSION ")";
 
-extern int dods_keep_temps;     // defined in HTTPResponse.h
+extern int libdap::dods_keep_temps;     // defined in HTTPResponse.h
 
 void usage(string name)
 {
