@@ -35,8 +35,13 @@
 
 #include "config.h"
 
-#ifndef WIN32
+#include <cstring>
+
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+
+#ifndef WIN32
 #else
 #include <io.h>
 #include <fcntl.h>
