@@ -35,18 +35,20 @@
 
 #include "config.h"
 
-static char rcsid[] not_used = {"$Id: dds-test.cc 13272 2006-02-24 19:36:05Z jimg $"};
+static char rcsid[] not_used = {"$Id: dds-test.cc 18286 2008-03-01 03:24:05Z jimg $"};
 
 #include <GetOpt.h>
 
 #include "parser.h"
-#include "dds.tab.h"
+#include "dds.tab.hh"
 #include "BaseType.h"
 #include "Int32.h"
 #include "DDS.h"
 #include "util.h"
 #include "Error.h"
 
+using namespace libdap ;
+
 void test_scanner();
 void test_parser();
 void test_class();
