@@ -38,7 +38,7 @@
 //#define DODS_DEBUG 0
 
 static char rcsid[] not_used =
-    { "$Id: expr-test.cc 17371 2007-11-12 18:46:01Z jimg $" };
+    { "$Id: expr-test.cc 18286 2008-03-01 03:24:05Z jimg $" };
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -66,7 +66,7 @@ static char rcsid[] not_used =
 
 #include "parser.h"
 #include "expr.h"
-#include "ce_expr.tab.h"
+#include "ce_expr.tab.hh"
 #include "util.h"
 #include "debug.h"
 
