@@ -25,7 +25,11 @@
  
 // Tests for the AISResources class.
 
+#include "config.h"
+
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 
 #include <algorithm>
 #include <stdexcept>
@@ -36,9 +40,13 @@
 
 #include "AISResources.h"
 #include "debug.h"
+#include <test_config.h>
 
 using namespace CppUnit;
 
+namespace libdap
+{
+
 class AISResourcesTest:public TestFixture {
 private:
     AISResources *ais;
@@ -50,21 +58,21 @@ public:
     ~AISResourcesTest() {} 
 
     void setUp() {
-	fnoc1 = "http://test.opendap.org/opendap/nph-dods/data/nc/fnoc1.nc";
-	fnoc2 = "http://test.opendap.org/opendap/nph-dods/data/nc/fnoc2.nc";
-	fnoc3 = "http://test.opendap.org/opendap/nph-dods/data/nc/fnoc3.nc";
+	fnoc1 = "http://test.opendap.org/opendap/data/nc/fnoc1.nc";
+	fnoc2 = "http://test.opendap.org/opendap/data/nc/fnoc2.nc";
+	fnoc3 = "http://test.opendap.org/opendap/data/nc/fnoc3.nc";
 
-	regexp = "http://test.opendap.org/opendap/nph-dods/data/nc/[0-9]+.*\\.nc";
-	bears = "http://test.opendap.org/opendap/nph-dods/data/nc/123bears.nc";
-	three_fnoc = "http://test.opendap.org/opendap/nph-dods/data/nc/3fnoc.nc";
-	one_2_3 = "http://test.opendap.org/opendap/nph-dods/data/nc/123.nc";
+	regexp = "http://test.opendap.org/opendap/data/nc/[0-9]+.*\\.nc";
+	bears = "http://test.opendap.org/opendap/data/nc/123bears.nc";
+	three_fnoc = "http://test.opendap.org/opendap/data/nc/3fnoc.nc";
+	one_2_3 = "http://test.opendap.org/opendap/data/nc/123.nc";
 
 
 	fnoc1_ais = "http://test.opendap.org/ais/fnoc1.nc.das";
-	fnoc2_ais = "ais_testsuite/fnoc2_replace.das";
+	fnoc2_ais = (string)TEST_SRC_DIR + "/ais_testsuite/fnoc2_replace.das";
 	fnoc3_ais = "http://test.opendap.org/ais/fnoc3_fallback.das";
-	digit_ais = "ais_testsuite/starts_with_number.das";
-	one_2_3_ais = "ais_testsuite/123.das";
+	digit_ais = (string)TEST_SRC_DIR + "/ais_testsuite/starts_with_number.das";
+	one_2_3_ais = (string)TEST_SRC_DIR + "/ais_testsuite/123.das";
 
 	ais = new AISResources;
 
@@ -304,6 +312,8 @@ public:
 
 CPPUNIT_TEST_SUITE_REGISTRATION(AISResourcesTest);
 
+} // namespace libdap
+
 int 
 main( int, char** )
 {
