@@ -34,19 +34,16 @@
 #include "debug.h"
 #include "util.h"
 #include "escaping.h"
-#include <assert.h>
+
+#include <cstring>
 #include <string>
 
 using std::cerr;
 using std::endl;
 using std::string;
 
-string hexstring(unsigned char val); // originally declared static
-string unhexstring(string s);
-
 using namespace CppUnit;
-using std::cerr ;
-using std::endl ;
+using namespace libdap;
 
 class generalUtilTest : public TestFixture {
 private:
@@ -73,7 +70,10 @@ public:
     CPPUNIT_TEST(escattr_test);
     CPPUNIT_TEST(unescattr_test);
     CPPUNIT_TEST(munge_error_message_test);
+#if 0
+    // Moved function to HTTPConnect.cc
     CPPUNIT_TEST(get_tempfile_template_test);
+#endif
     CPPUNIT_TEST(id2xml_test);
     CPPUNIT_TEST(xml2id_test);
 
@@ -235,6 +235,8 @@ public:
 	CPPUNIT_ASSERT(munge_error_message(str) == str1);
     }
 
+#if 0
+    // Moved function to HTTPConect.
     void get_tempfile_template_test() {
 #ifdef WIN32
 	if (_putenv("TMPDIR=C:\\") == 0) {
@@ -262,7 +264,8 @@ public:
 			      tmplt.c_str()) == 0);
 #endif
     }
-
+#endif
+    
     void id2xml_test() {
 	CPPUNIT_ASSERT(id2xml("abcdef") == "abcdef");
 	CPPUNIT_ASSERT(id2xml("abc<def") == "abc&lt;def");
