@@ -36,7 +36,7 @@
 #ifndef _util_h
 #define _util_h 1
 
-#include <stdio.h>
+#include <cstdio>
 #include <vector>
 
 #ifndef _basetype_h
@@ -95,8 +95,15 @@
 #include "Grid.h"
 #endif
 
+#ifdef _MSC_VER
+#define uint unsigned int
+#endif
+
 using std::iostream;
 
+namespace libdap
+{
+
 string prune_spaces(const string &);
 bool unique_names(vector<BaseType *> l, const string &var, const string &type,
                   string &msg);
@@ -117,6 +124,8 @@ void flush_stream(iostream ios, FILE *out);
 #endif
 
 void downcase(string &s);
+string remove_quotes(const string &s);
+
 // Jose Garcia
 /** @name Integer to string conversion functions
    Fast, safe conversions from long to a character representation which gets
@@ -183,6 +192,8 @@ string dap_version();
     @return A string containing only the filename given a path. */
 string path_to_filename(string path);
 
+#if 0
+// Moved to HTTPConnect.cc - the only file where it's used.
 /** Build a template for a temporary file suitable for use with mkstemp.
     Look around for a reasonable place to put a temporary file. Check first
     the value of the TMPDIR env var. If that does not yield a path that's
@@ -198,7 +209,7 @@ string path_to_filename(string path);
     @return A writable char[] that holds the fully qualified
     filename/template to use with mkstemp. */
 char *get_tempfile_template(char *file_template);
-
+#endif
 FILE *get_temp_file(char *temp);
 string file_to_string(FILE *fp);
 
@@ -207,4 +218,6 @@ time_t parse_time(const char * str, bool expand);
 bool size_ok(uint sz, uint nelem);
 bool pathname_ok(const string &path, bool strict = true);
 
+} // namespace libdap
+
 #endif
