@@ -30,11 +30,11 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: util_mit.cc 16088 2007-03-28 21:42:19Z jimg $"
+    {"$Id: util_mit.cc 18315 2008-03-03 20:14:44Z jimg $"
     };
 
-#include <stdio.h>
-#include <stdlib.h>
+#include <cstring>
+#include <cstdlib>
 #include <string>
 #include <ctype.h>
 
@@ -57,6 +57,8 @@ using std::string;
 
 #include "debug.h"
 
+namespace libdap {
+
 static char * months[12] =
     {
         "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
@@ -361,3 +363,5 @@ string date_time_str(time_t *calendar, bool local)
 #endif
     return string(buf);
 }
+
+} // namespace libdap
